JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
metaform: fix mtime trick for css file in html editors
[wfpl.git] / db.php
diff --git a/db.php b/db.php
index c137d03..5ac36a3 100644 (file)
--- a/db.php
+++ b/db.php
@@ -1,25 +1,16 @@
 <?php
 
-#  Copyright (C) 2006 Jason Woofenden
-#
-#  This program is free software: you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation, either version 3 of the License, or
-#  (at your option) any later version.
-#  
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#  
-#  You should have received a copy of the GNU General Public License
-#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# This program is in the public domain within the United States. Additionally,
+# we waive copyright and related rights in the work worldwide through the CC0
+# 1.0 Universal public domain dedication, which can be found at
+# http://creativecommons.org/publicdomain/zero/1.0/
 
 
 require_once(__DIR__.'/'.'encode.php');
 require_once(__DIR__.'/'.'format.php');
 
# db_connect() -- connect to a mysql database
 #
 # PARAMETERS:
 #
@@ -37,12 +28,14 @@ require_once(__DIR__.'/'.'format.php');
 #
 #   the database connection handle. You'll only need this if you want to have
 #   multiple databases open at once.
-
-function db_enc_sql($str) {
-       return mysqli_real_escape_string(isset($GLOBALS['wfpl_db_handle']) ? $GLOBALS['wfpl_db_handle'] : null, $str);
+function db_connect() {
+       if (isset($GLOBALS['wfpl_db_handle'])) {
+               mysqli_close($GLOBALS['wfpl_db_handle']);
+               unset($GLOBALS['wfpl_db_handle']);
+       }
+       $GLOBALS['wfpl_db_connect_args'] = func_get_args();
 }
-
-function db_connect($database = 'auto', $user = 'auto', $pass = 'auto', $host = 'localhost', $encoding = 'utf8') {
+function db_connect_now($database = 'auto', $user = 'auto', $pass = 'auto', $host = 'localhost', $encoding = 'utf8') {
        if($database == 'auto') {
                if(isset($GLOBALS['db_name'])) {
                        $database = $GLOBALS['db_name'];
@@ -71,9 +64,10 @@ function db_connect($database = 'auto', $user = 'auto', $pass = 'auto', $host =
                }
        }
 
-       $GLOBALS['wfpl_db_handle'] = mysqli_connect($host, $user, $pass);
+       $GLOBALS['wfpl_db_handle'] = @mysqli_connect($host, $user, $pass);
        if(!$GLOBALS['wfpl_db_handle']) {
-               die('Could not connect to the database: ' . mysqli_error());
+               die('Server error: Database connection failed');
+               # to show username and host: mysqli_connect_error()
        }
 
        mysqli_set_charset($GLOBALS['wfpl_db_handle'], $encoding);
@@ -84,9 +78,25 @@ function db_connect($database = 'auto', $user = 'auto', $pass = 'auto', $host =
 
        return $GLOBALS['wfpl_db_handle'];
 }
+# for internal use (helps implement the auto-connect feature of db_connect())
+function _db_connection_needed() {
+       if (isset($GLOBALS['wfpl_db_handle'])) {
+               return;
+       }
+       if (isset($GLOBALS['wfpl_db_connect_args'])) {
+               return call_user_func_array('db_connect_now', $GLOBALS['wfpl_db_connect_args']);
+       }
+       die('Error: you must call db_connect() or db_auto_connect() first!');
+}
+
+function db_enc_sql($str) {
+       _db_connection_needed();
+       return mysqli_real_escape_string(isset($GLOBALS['wfpl_db_handle']) ? $GLOBALS['wfpl_db_handle'] : null, $str);
+}
 
 # Unless you're doing something unusual like an ALTER TABLE don't call this directly
 function db_send_query($sql) {
+       _db_connection_needed();
        #echo("Sending query: " . enc_html($sql) . "<br>\n");
        $result = mysqli_query($GLOBALS['wfpl_db_handle'], $sql);
        if(!$result) {
@@ -313,6 +323,7 @@ function db_replace($table, $columns, $values) {
        
 # return the value mysql made up for the auto_increment field (for the last insert)
 function db_auto_id() {
+       _db_connection_needed();
        return mysqli_insert_id($GLOBALS['wfpl_db_handle']);
 }
@@ -1,25 +1,16 @@
 require_once(__DIR__.'/'.'format.php');
 
-# db_connect() -- connect to a mysql database
+# db_connect() -- connect to a mysql database (automatically, later, when/if needed)
+# db_connect_now() -- connect to a mysql database immediately
 #
 # PARAMETERS: